from operator import itemgetter
from nltk.tokenize import word_tokenize
from nltk.stem.snowball import SnowballStemmer


hinges_backup = ["denn", "und", "doch", "denn", "wenn",
                 "als", "bis", "weil", "da", "damit", "solange"]

hinges_all = ["und", 'aber', 'allerdings', 'als', 'also', 'andernfalls', 'anders gesagt', 'angenommen', 'anschließend', 'ansonsten', 'auf ... hin', 'aufgrund', 'außerdem', 'bedingt', 'bevor', 'bewirkt', 'beziehungsweise', 'da', 'dabei', 'dadurch', 'dadurch... dass', 'dafür', 'dagegen', 'daher', 'damals', 'damit', 'danach', 'daneben', 'dank', 'dann', 'darauf', 'darum', 'das heißt', 'dass', 'davor', 'dazu', 'demgegenüber', 'demnach', 'demzufolge', 'denn', 'dennoch', 'dermaßen... dass', 'desgleichen', 'deshalb', 'deswegen', 'doch', 'durch', 'ebenso', 'ehe', 'einerseits ...andererseits', 'einfacher', 'endlich', 'entgegen', 'ergo', 'es sei denn', 'falls', 'ferner', 'folgendermaßen', 'folglich', 'freilich', 'früher', 'führt dazu', 'für',
              'gegebenenfalls', 'gegen', 'genauer gesagt', 'gesetzt', 'gleichwohl', 'hingegen', 'im Gegenteil', 'im Klartext', 'immerhin', 'indem', 'indessen', 'infolge', 'infolgedessen', 'insofern', 'ja', 'jedoch', 'mit', 'mithin', 'mittels', 'nach', 'nachdem', 'notfalls', 'nur', 'nämlich', 'obgleich', 'obwohl', 'oder auch', 'ohne', 'resultiert aus', 'seit', 'so', 'so dass', 'sobald', 'sofern', 'somit', 'sondern', 'sonst', 'sowieso', 'später', 'stattdessen', 'trotz', 'trotzdem', 'um... willen', 'um... zu', 'und dann', 'und zwar', 'vielmehr', 'vor', 'vorausgesetzt...dass', 'wegen', 'weil', 'weiter', 'wenn', 'wenn... auch', 'weshalb', 'weswegen', 'wider', 'wodurch', 'wogegen', 'während', 'währenddessen', 'zudem', 'zum/ zur', 'zusätzlich', 'zuvor', 'zwecks']

hinges = ['jener', 'derselbe', 'was', 'alle', 'dass', 'von', 'im', 'den', 'welcher', 'als', 'welche',
          'das', 'wie', 'zu', 'derjenige', 'dem', 'und', 'der', 'auf', 'mit', 'durch', 'oder', 'so', 'die']


keywords = ["Inhalt", "Form", "Sinn", "Bedeutung"]


def check_text(*texts):
    """
    Get statistics of one or two Text()

    Parameters:s
    arg (Text()): instance of Text() class

    Returns:
    str: keywords and hinges
    """
    for text in texts:
        line = (len(text.name)+1)*"-"
        info = ""
        info += f"{line} \n {text.name}\n{line}\n"
        for dict_keyword in text.dict:
            sub_dict = text.dict[dict_keyword]
            for hinge_list in sub_dict:
                info += f"{dict_keyword}/{hinge_list}: {len(sub_dict[hinge_list])}\n"
        print(info)


def commons(text1, text2):
    """
    common words of multiple Text objects

    Parameters:
    Text()

    Returns:
    dict of common words
    """

    def get_keys():
        key_list = text1_token_stem  # base list
        key_list = set(key_list) & set(text2_token_stem)
        return key_list

    def get_stats():
        stats_dict = {}
        for key in key_list:
            stats_dict[key] = [0, 0]
            for word in text1_token_stem:
                if word == key:
                    stats_dict[key][0] += 1
            for word in text2_token_stem:
                if word == key:
                    stats_dict[key][1] += 1
        stats_dict_sorted = dict(sorted(
            stats_dict.items(), key=lambda x: x[1], reverse=True))
        return stats_dict_sorted

    sst = SnowballStemmer("german")
    text1_token_stem = [sst.stem(word).lower()
                        for word in word_tokenize(text1.text)]
    text2_token_stem = [sst.stem(word).lower()
                        for word in word_tokenize(text2.text)]
    key_list = get_keys()
    stats = get_stats()
    return stats


def layout(dictionary):
    """
    layouts dictionary as string in rows

    Parameters:
    dict()

    Returns:
    str
    """

    dict_layout = ""
    for key, value in dictionary.items():
        dict_layout += f"{key}: {value[0]}/{value[1]}\n"
    return dict_layout
